**EN 1993-1-1 - May 2005
Eurocode 3: Design of steel structures
Part 1-1: General rules and rules for buildings**

The table presents a list of tables from the Eurocode 3 standards for steel structures, tracking their implementation status (:x: or :heavy_check_mark:)
and any pertinent remarks. The 'Object Name' column references the corresponding Python entities inside of Blueprints.

Total of 20 tables present.

| Table number | Done | Remarks | Object name |
|:-------------|:----:|:--------|:------------|
| 3.1          | :x:  |         | Table3Dot1NominalValuesHotRolledStructuralSteel |
| 3.2          | :x:  |         |             |
| 5.1          | :x:  |         |             |
| 5.2          | :x:  |         |             |
| 6.1          | :x:  |         |             |
| 6.2          | :x:  |         |             |
| 6.3          | :x:  |         |             |
| 6.4          | :x:  |         |             |
| 6.5          | :x:  |         |             |
| 6.6          | :x:  |         |             |
| 6.7          | :x:  |         |             |
| 6.8          | :x:  |         |             |
| 6.9          | :x:  |         |             |
| A.1          | :x:  |         |             |
| A.2          | :x:  |         |             |
| B.1          | :x:  |         |             |
| B.2          | :x:  |         |             |
| B.3          | :x:  |         |             |
| BB.1         | :x:  |         |             |
| C.1          | :x:  |         |             |
